==> nextcloud-24.0.9.tgz: nextcloud/apps/workflowengine/l10n/eu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zehaztutako eragilea baliogabea da",
    "The given regular expression is invalid" : "Zehaztutako adierazpen erregularra baliogabea da",
    "The given file size is invalid" : "Zehaztutako fitxategi tamaina baliogabea da",
    "The given tag id is invalid" : "Zehaztutako etiketa baliogabea da",
    "The given IP range is invalid" : "Zehaztutako IP barrutia baliogabea da",
    "The given IP range is not valid for IPv4" : "Zehaztutako IP barrutia baliogabea da IPv4rako",
    "The given IP range is not valid for IPv6" : "Zehaztutako IP barrutia baliogabea da IPv6rako",
    "The given time span is invalid" : "Zehaztutako denbora tartea baliogabea da",
    "The given start time is invalid" : "Zehaztutako hasiera-ordua baliogabea da",
    "The given end time is invalid" : "Zehaztutako amaiera-ordua baliogabea da",
    "The given group does not exist" : "Ez dago zehaztutako talde hori",
    "File" : "Fitxategia",
    "File created" : "Fitxategia sortu da",
    "File updated" : "Fitxategia eguneratuta",
    "File renamed" : "Fitxategiaren izena aldatu da",
    "File deleted" : "Fitxategia ezabatuta",
    "File accessed" : "Fitxategia atzituta",
    "File copied" : "Fitxategia kopiatu da",
    "Tag assigned" : "Etiketa esleitu da",
    "Someone" : "Norbait",
    "%s created %s" : "%s(e)k %s sortu du",
    "%s modified %s" : "%s(e)k %s aldatu du",
    "%s deleted %s" : "%s(e)k %s ezabatu du",
    "%s accessed %s" : "%s(e)k %s atzitu du",
    "%s renamed %s" : "%s(e)k %s izenez aldatu du",
    "%s copied %s" : "%s(e)k %s kopiatu du",
    "%s assigned %s to %s" : "%s(e)k %s esleitu dio %s(r)i",
    "Operation #%s does not exist" : "Ez dago #%s eragiketarik",
    "Entity %s does not exist" : "Ez dago %s entitaterik",
    "Entity %s is invalid" : "%s entitatea baliogabea da",
    "No events are chosen." : "Ez da gertaerarik aukeratu.",
    "Entity %s has no event %s" : "%s entitateak ez du %s gertaerarik",
    "Operation %s does not exist" : "Ez dago %s eragiketarik",
    "Operation %s is invalid" : "%seragiketa baliogabea da",
    "At least one check needs to be provided" : "Gutxienez egiaztapen bat eman behar da",
    "The provided operation data is too long" : "Emandako eragiketa datuak luzeegiak dira.",
    "Invalid check provided" : "Baliogabeko egiaztapena eman da",
    "Check %s does not exist" : "%segiaztapena ez dago",
    "Check %s is invalid" : "%segiaztapena baliogabea da",
    "Check %s is not allowed with this entity" : "%segiaztapena ez da onartzen entitate honekin",
    "The provided check value is too long" : "Emandako egiaztatze balioa luzeegia da.",
    "Check #%s does not exist" : "#%s egiaztapena ez dago",
    "Check %s is invalid or does not exist" : "%s egiaztapena baliogabea da edo ez dago",
    "Flow" : "Fluxua",
    "Nextcloud workflow engine" : "Nextcloud lan-fluxu motorra",
    "Select a filter" : "Hautatu iragazki bat",
    "Select a comparator" : "Hautatu konparatzailea",
    "Select a file type" : "Hautatu fitxategi mota bat",
    "e.g. httpd/unix-directory" : "adib. httpd/unix-direktorioa",
    "Folder" : "Karpeta",
    "Images" : "Irudiak",
    "Office documents" : "Office dokumentuak",
    "PDF documents" : "PDF dokumentuak",
    "Custom MIME type" : "MIME mota pertsonalizatua",
    "Custom mimetype" : "Mime mota pertsonalizatua",
    "Please enter a valid time span" : "Sartu baliozko denbora tarte bat",
    "Select a request URL" : "Hautatu eskaera URL bat",
    "Predefined URLs" : "Aurrez definitutako URL-ak",
    "Files WebDAV" : "WebDAV fitxategiak",
    "Others" : "Bestelakoak",
    "Custom URL" : "URL pertsonalizatua",
    "Select a user agent" : "Hautatu erabiltzaile-agentea",
    "Android client" : "Android bezeroa",
    "iOS client" : "iOS bezeroa",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Thunderbird & Outlook addons" : "Thunderbird eta Outlook gehigarriak",
    "Custom user agent" : "Erabiltzaile-agente pertsonalizatua",
    "At least one event must be selected" : "Gutxienez gertaera bat hautatu behar da",
    "Add new flow" : "Gehitu fluxu berria",
    "When" : "Noiz",
    "and" : "eta",
    "Cancel" : "Utzi",
    "Delete" : "Ezabatu",
    "The configuration is invalid" : "Konfigurazioa baliogabea da",
    "Active" : "Aktiboa",
    "Save" : "Gorde",
    "Available flows" : "Fluxu erabilgarriak",
    "For details on how to write your own flow, check out the development documentation." : "Zeure fluxua idazten jakiteko informazioa lortzeko, begiratu garatzaileen dokumentazioa.",
    "More flows" : "Fluxu gehiago",
    "Browse the App Store" : "Arakatu aplikazio biltegia",
    "Show less" : "Erakutsi gutxiago",
    "Show more" : "Erakutsi gehiago",
    "Configured flows" : "Konfiguratutako fluxuak",
    "Your flows" : "Zure fluxuak",
    "matches" : "bat dator",
    "does not match" : "ez dator bat",
    "is" : "da",
    "is not" : "ez da",
    "File name" : "Fitxategi-izena",
    "File MIME type" : "Fitxategiaren MIME mota",
    "File size (upload)" : "Fitxategiaren tamaina (kargatzea)",
    "less" : "gutxiago",
    "less or equals" : "gutxiago edo berdin",
    "greater or equals" : "handiagoa edo berdina",
    "greater" : "handiagoa ",
    "Request remote address" : "Eskatu urruneko helbidea",
    "matches IPv4" : "bat dator IPv4rekin",
    "does not match IPv4" : "ez dator bat IPv4rekin",
    "matches IPv6" : "bat dator IPv6rekin",
    "does not match IPv6" : "ez dator bat IPv6rekin",
    "File system tag" : "Fitxategi-sistemako etiketa",
    "is tagged with" : "honela etiketatuta dago:",
    "is not tagged with" : "ez dago honela etiketatuta:",
    "Request URL" : "Eskaera-URLa",
    "Request time" : "Eskaera-denbora",
    "between" : "bitarte honetan",
    "not between" : "ez dago bitarte honetan",
    "Request user agent" : "Eskatu erabiltzaile-agentea",
    "User group membership" : "Erabiltzailearen talde-kidetza",
    "is member of" : "hemengo kide da:",
    "is not member of" : "ez da hemengo kide:",
    "Select a tag" : "Hautatu etiketa bat",
    "No results" : "Emaitzarik ez",
    "%s (invisible)" : "%s (ikusezina)",
    "%s (restricted)" : "%s (mugatua)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.7.tgz: nextcloud/apps/workflowengine/l10n/eu.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Zehaztutako eragilea baliogabea da",
    "The given regular expression is invalid" : "Zehaztutako adierazpen erregularra baliogabea da",
    "The given file size is invalid" : "Zehaztutako fitxategi tamaina baliogabea da",
    "The given tag id is invalid" : "Zehaztutako etiketa baliogabea da",
    "The given IP range is invalid" : "Zehaztutako IP barrutia baliogabea da",
    "The given IP range is not valid for IPv4" : "Zehaztutako IP barrutia baliogabea da IPv4rako",
    "The given IP range is not valid for IPv6" : "Zehaztutako IP barrutia baliogabea da IPv6rako",
    "The given time span is invalid" : "Zehaztutako denbora tartea baliogabea da",
    "The given start time is invalid" : "Zehaztutako hasiera-ordua baliogabea da",
    "The given end time is invalid" : "Zehaztutako amaiera-ordua baliogabea da",
    "The given group does not exist" : "Ez dago zehaztutako talde hori",
    "File" : "Fitxategia",
    "File created" : "Fitxategia sortu da",
    "File updated" : "Fitxategia eguneratuta",
    "File renamed" : "Fitxategiaren izena aldatu da",
    "File deleted" : "Fitxategia ezabatuta",
    "File accessed" : "Fitxategia atzituta",
    "File copied" : "Fitxategia kopiatu da",
    "Tag assigned" : "Etiketa esleitu da",
    "Someone" : "Norbait",
    "%s created %s" : "%s(e)k %s sortu du",
    "%s modified %s" : "%s(e)k %s aldatu du",
    "%s deleted %s" : "%s(e)k %s ezabatu du",
    "%s accessed %s" : "%s(e)k %s atzitu du",
    "%s renamed %s" : "%s(e)k %s izenez aldatu du",
    "%s copied %s" : "%s(e)k %s kopiatu du",
    "%s assigned %s to %s" : "%s(e)k %s esleitu dio %s(r)i",
    "Operation #%s does not exist" : "Ez dago #%s eragiketarik",
    "Entity %s does not exist" : "Ez dago %s entitaterik",
    "Entity %s is invalid" : "%s entitatea baliogabea da",
    "No events are chosen." : "Ez da gertaerarik aukeratu.",
    "Entity %s has no event %s" : "%s entitateak ez du %s gertaerarik",
    "Operation %s does not exist" : "Ez dago %s eragiketarik",
    "Operation %s is invalid" : "%seragiketa baliogabea da",
    "At least one check needs to be provided" : "Gutxienez egiaztapen bat eman behar da",
    "The provided operation data is too long" : "Emandako eragiketa datuak luzeegiak dira.",
    "Invalid check provided" : "Baliogabeko egiaztapena eman da",
    "Check %s does not exist" : "%segiaztapena ez dago",
    "Check %s is invalid" : "%segiaztapena baliogabea da",
    "Check %s is not allowed with this entity" : "%segiaztapena ez da onartzen entitate honekin",
    "The provided check value is too long" : "Emandako egiaztatze balioa luzeegia da.",
    "Check #%s does not exist" : "#%s egiaztapena ez dago",
    "Check %s is invalid or does not exist" : "%s egiaztapena baliogabea da edo ez dago",
    "Flow" : "Fluxua",
    "Nextcloud workflow engine" : "Nextcloud lan-fluxu motorra",
    "Select a filter" : "Hautatu iragazki bat",
    "Select a comparator" : "Hautatu konparatzailea",
    "Select a file type" : "Hautatu fitxategi mota bat",
    "e.g. httpd/unix-directory" : "adib. httpd/unix-direktorioa",
    "Folder" : "Karpeta",
    "Images" : "Irudiak",
    "Office documents" : "Office dokumentuak",
    "PDF documents" : "PDF dokumentuak",
    "Custom MIME type" : "MIME mota pertsonalizatua",
    "Custom mimetype" : "Mime mota pertsonalizatua",
    "Please enter a valid time span" : "Sartu baliozko denbora tarte bat",
    "Select a request URL" : "Hautatu eskaera URL bat",
    "Files WebDAV" : "WebDAV fitxategiak",
    "Custom URL" : "URL pertsonalizatua",
    "Select a user agent" : "Hautatu erabiltzaile-agentea",
    "Android client" : "Android bezeroa",
    "iOS client" : "iOS bezeroa",
    "Desktop client" : "Mahaigaineko bezeroa",
    "Thunderbird & Outlook addons" : "Thunderbird eta Outlook gehigarriak",
    "Custom user agent" : "Erabiltzaile-agente pertsonalizatua",
    "At least one event must be selected" : "Gutxienez gertaera bat hautatu behar da",
    "Add new flow" : "Gehitu fluxu berria",
    "When" : "Noiz",
    "and" : "eta",
    "Cancel" : "Utzi",
    "Delete" : "Ezabatu",
    "The configuration is invalid" : "Konfigurazioa baliogabea da",
    "Active" : "Aktiboa",
    "Save" : "Gorde",
    "Available flows" : "Fluxu erabilgarriak",
    "For details on how to write your own flow, check out the development documentation." : "Zeure fluxua idazten jakiteko informazioa lortzeko, begiratu garatzaileen dokumentazioa.",
    "More flows" : "Fluxu gehiago",
    "Browse the App Store" : "Arakatu aplikazio biltegia",
    "Show less" : "Erakutsi gutxiago",
    "Show more" : "Erakutsi gehiago",
    "Configured flows" : "Konfiguratutako fluxuak",
    "Your flows" : "Zure fluxuak",
    "matches" : "bat dator",
    "does not match" : "ez dator bat",
    "is" : "da",
    "is not" : "ez da",
    "File name" : "Fitxategi-izena",
    "File MIME type" : "Fitxategiaren MIME mota",
    "File size (upload)" : "Fitxategiaren tamaina (kargatzea)",
    "less" : "gutxiago",
    "less or equals" : "gutxiago edo berdin",
    "greater or equals" : "handiagoa edo berdina",
    "greater" : "handiagoa ",
    "Request remote address" : "Eskatu urruneko helbidea",
    "matches IPv4" : "bat dator IPv4rekin",
    "does not match IPv4" : "ez dator bat IPv4rekin",
    "matches IPv6" : "bat dator IPv6rekin",
    "does not match IPv6" : "ez dator bat IPv6rekin",
    "File system tag" : "Fitxategi-sistemako etiketa",
    "is tagged with" : "honela etiketatuta dago:",
    "is not tagged with" : "ez dago honela etiketatuta:",
    "Request URL" : "Eskaera-URLa",
    "Request time" : "Eskaera-denbora",
    "between" : "bitarte honetan",
    "not between" : "ez dago bitarte honetan",
    "Request user agent" : "Eskatu erabiltzaile-agentea",
    "User group membership" : "Erabiltzailearen talde-kidetza",
    "is member of" : "hemengo kide da:",
    "is not member of" : "ez da hemengo kide:",
    "Select a tag" : "Hautatu etiketa bat",
    "No results" : "Emaitzarik ez",
    "%s (invisible)" : "%s (ikusezina)",
    "%s (restricted)" : "%s (mugatua)",
    "Predefined URLs" : "Aurrez definitutako URL-ak",
    "Others" : "Bestelakoak"
},
"nplurals=2; plural=(n != 1);");
